==> haskell-network-ip-0.3.0.3-468.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-CPrEVCVHqj3xsde91Vvpj
key:                  network-ip-0.3.0.3-CPrEVCVHqj3xsde91Vvpj
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  d0d6bfe06390409d96ad55e661157ec9
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-CPrEVCVHqj3xsde91Vvpj
depends:
    base-4.18.2.1 data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    data-dword-0.3.2.1-Etw3X3VgSqh8bxGGtukvQ5
    data-endian-0.1.1-AArotBb6YVx66xbeUMCKUi
    data-serializer-0.3.5-LCo3k9EPCpDUjqxiSHpwP
    data-textual-0.3.0.3-LWd5CFCTedNKsLwqPW4jo8
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT
    text-printer-0.5.0.2-7dUulcQwVwPCJ4EFOY5An3
    type-hint-0.1-DOljIsV2uPAHVcEmWbYknQ

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-ip-0.3.0.3-469-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-ip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-ip
version:              0.3.0.3
visibility:           public
id:                   network-ip-0.3.0.3-F4S0hl1urBII3K2hMgQak8
key:                  network-ip-0.3.0.3-F4S0hl1urBII3K2hMgQak8
license:              BSD-3-Clause
copyright:            2011-2016 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/network-ip
synopsis:             Internet Protocol data structures
description:          This package provides Internet Protocol data structures
category:             Network
abi:                  8be03125073dab2b643a6679bda8a47b
exposed:              True
exposed-modules:      Network.IP.Addr
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-ip-0.3.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-ip
hs-libraries:         HSnetwork-ip-0.3.0.3-F4S0hl1urBII3K2hMgQak8
depends:
    base-4.18.2.1 data-default-class-0.1.2.2-CDKXYK1wrFx3d5as0Pbjkc
    data-dword-0.3.2.1-B7lOaQm5BeP18AmlmArfWW
    data-endian-0.1.1-AArotBb6YVx66xbeUMCKUi
    data-serializer-0.3.5-5CABA8JdaLPGBow7GqzVt9
    data-textual-0.3.0.3-6Ou9Tf2REVc5yawnM2oba5
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    parsers-0.12.12-PO1r5WusBRCqoNlSszPjk
    text-printer-0.5.0.2-BYXc0vw9GxDJWKFuxOXvjc
    type-hint-0.1-DOljIsV2uPAHVcEmWbYknQ

haddock-interfaces:   /usr/share/doc/haskell-network-ip/html/network-ip.haddock
haddock-html:         /usr/share/doc/haskell-network-ip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
